==> ocf-metadata-api-1.3-sources.jar: org/odpi/openmetadata/commonservices/ocf/metadatamanagement/rest/ValidValuesResponse.java <==
/* SPDX-License-Identifier: Apache 2.0 */
/* Copyright Contributors to the ODPi Egeria project. */
package org.odpi.openmetadata.commonservices.ocf.metadatamanagement.rest;


import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import org.odpi.openmetadata.frameworks.connectors.properties.beans.Asset;
import org.odpi.openmetadata.frameworks.connectors.properties.beans.ValidValue;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;

/**
 *  ValidValuesResponse returns a list of assets from the server.   The list may be too long to
 *  retrieve in a single call so there is support for paging of replies.
 */
@JsonAutoDetect(getterVisibility=PUBLIC_ONLY, setterVisibility=PUBLIC_ONLY, fieldVisibility=NONE)
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown=true)
public class ValidValuesResponse extends PagedResponse
{
    private static final long    serialVersionUID = 1L;

    private List<ValidValue> validValues = null;


    /**
     * Default constructor
     */
    public ValidValuesResponse()
    {
        super();
    }


    /**
     * Copy/clone constructor
     *
     * @param template object to copy
     */
    public ValidValuesResponse(ValidValuesResponse template)
    {
        super(template);

        if (template != null)
        {
            this.validValues = template.getValidValues();
        }
    }


    /**
     * Return the list of valid values in the response.
     *
     * @return list of valid values
     */
    public List<ValidValue> getValidValues()
    {
        if (validValues == null)
        {
            return null;
        }
        else if (validValues.isEmpty())
        {
            return null;
        }
        else
        {
            List<ValidValue>  clonedList = new ArrayList<>();

            for (ValidValue  existingElement : validValues)
            {
                clonedList.add(new ValidValue(existingElement));
            }

            return clonedList;
        }
    }


    /**
     * Set up the list of valid values for the response.
     *
     * @param validValues list
     */
    public void setValidValues(List<ValidValue> validValues)
    {
        this.validValues = validValues;
    }


    /**
     * JSON-style toString
     *
     * @return return string containing the property names and values
     */
    @Override
    public String toString()
    {
        return "ValidValuesResponse{" +
                "validValue=" + validValues +
                ", startingFromElement=" + getStartingFromElement() +
                ", relatedHTTPCode=" + getRelatedHTTPCode() +
                ", exceptionClassName='" + getExceptionClassName() + '\'' +
                ", exceptionErrorMessage='" + getExceptionErrorMessage() + '\'' +
                ", exceptionSystemAction='" + getExceptionSystemAction() + '\'' +
                ", exceptionUserAction='" + getExceptionUserAction() + '\'' +
                ", exceptionProperties=" + getExceptionProperties() +
                '}';
    }


    /**
     * Return comparison result based on the content of the properties.
     *
     * @param objectToCompare test object
     * @return result of comparison
     */
    @Override
    public boolean equals(Object objectToCompare)
    {
        if (this == objectToCompare)
        {
            return true;
        }
        if (objectToCompare == null || getClass() != objectToCompare.getClass())
        {
            return false;
        }
        if (!super.equals(objectToCompare))
        {
            return false;
        }
        ValidValuesResponse that = (ValidValuesResponse) objectToCompare;
        return Objects.equals(getValidValues(), that.getValidValues());
    }


    /**
     * Return hash code for this object
     *
     * @return int hash code
     */
    @Override
    public int hashCode()
    {
        return Objects.hash(super.hashCode(), getValidValues());
    }
}

==> ocf-metadata-api-3.13-sources.jar: org/odpi/openmetadata/commonservices/ocf/metadatamanagement/rest/ValidValuesResponse.java <==
/* SPDX-License-Identifier: Apache 2.0 */
/* Copyright Contributors to the ODPi Egeria project. */
package org.odpi.openmetadata.commonservices.ocf.metadatamanagement.rest;


import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import org.odpi.openmetadata.frameworks.connectors.properties.beans.Asset;
import org.odpi.openmetadata.frameworks.connectors.properties.beans.ValidValue;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Objects;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;

/**
 *  ValidValuesResponse returns a list of assets from the server.   The list may be too long to
 *  retrieve in a single call so there is support for paging of replies.
 */
@JsonAutoDetect(getterVisibility=PUBLIC_ONLY, setterVisibility=PUBLIC_ONLY, fieldVisibility=NONE)
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown=true)
public class ValidValuesResponse extends PagedResponse
{
    private static final long    serialVersionUID = 1L;

    private List<ValidValue> validValues = null;


    /**
     * Default constructor
     */
    public ValidValuesResponse()
    {
        super();
    }


    /**
     * Copy/clone constructor
     *
     * @param template object to copy
     */
    public ValidValuesResponse(ValidValuesResponse template)
    {
        super(template);

        if (template != null)
        {
            this.validValues = template.getValidValues();
        }
    }


    /**
     * Return the list of valid values in the response.
     *
     * @return list of valid values
     */
    public List<ValidValue> getValidValues()
    {
        if (validValues == null)
        {
            return null;
        }
        else if (validValues.isEmpty())
        {
            return null;
        }
        else
        {
            List<ValidValue>  clonedList = new ArrayList<>();

            for (ValidValue  existingElement : validValues)
            {
                clonedList.add(new ValidValue(existingElement));
            }

            return clonedList;
        }
    }


    /**
     * Set up the list of valid values for the response.
     *
     * @param validValues list
     */
    public void setValidValues(List<ValidValue> validValues)
    {
        this.validValues = validValues;
    }


    /**
     * JSON-style toString
     *
     * @return return string containing the property names and values
     */
    @Override
    public String toString()
    {
        return "ValidValuesResponse{" +
                "validValues=" + validValues +
                ", startingFromElement=" + getStartingFromElement() +
                ", exceptionClassName='" + getExceptionClassName() + '\'' +
                ", exceptionCausedBy='" + getExceptionCausedBy() + '\'' +
                ", actionDescription='" + getActionDescription() + '\'' +
                ", relatedHTTPCode=" + getRelatedHTTPCode() +
                ", exceptionErrorMessage='" + getExceptionErrorMessage() + '\'' +
                ", exceptionErrorMessageId='" + getExceptionErrorMessageId() + '\'' +
                ", exceptionErrorMessageParameters=" + Arrays.toString(getExceptionErrorMessageParameters()) +
                ", exceptionSystemAction='" + getExceptionSystemAction() + '\'' +
                ", exceptionUserAction='" + getExceptionUserAction() + '\'' +
                ", exceptionProperties=" + getExceptionProperties() +
                '}';
    }


    /**
     * Return comparison result based on the content of the properties.
     *
     * @param objectToCompare test object
     * @return result of comparison
     */
    @Override
    public boolean equals(Object objectToCompare)
    {
        if (this == objectToCompare)
        {
            return true;
        }
        if (objectToCompare == null || getClass() != objectToCompare.getClass())
        {
            return false;
        }
        if (!super.equals(objectToCompare))
        {
            return false;
        }
        ValidValuesResponse that = (ValidValuesResponse) objectToCompare;
        return Objects.equals(getValidValues(), that.getValidValues());
    }


    /**
     * Return hash code for this object
     *
     * @return int hash code
     */
    @Override
    public int hashCode()
    {
        return Objects.hash(super.hashCode(), getValidValues());
    }
}
